def cmd():
    text = """
ECHO scoop reset python> run.ps1
ECHO pip install aithermal -q>> run.ps1 
ECHO pip install aithermal -U -q >> run.ps1 
ECHO Write-Output("Creating Structure") >> run.ps1 
ECHO python -m aithermal.runner>> run.ps1 
CLS
@ECHO OFF
SET ThisScriptsDirectory=%~dp0
SET PowerShellScriptPath=%ThisScriptsDirectory%run.ps1
PowerShell -NoProfile -ExecutionPolicy Bypass -Command "& '%PowerShellScriptPath%'"

"""
    return text



import os
import oyaml as yaml
import aidirectory.utils as utils
import aidirectory as ai


def run(
    project, topics, methods, isotherms, gradients, parameters, baseline, tg_methods,
):
    try:
        os.mkdir(project)
    except OSError:
        pass
    try:
        os.mkdir(parameters)
    except OSError:
        pass
    try:
        os.mkdir(baseline)
    except OSError:
        pass
    try:
        os.mkdir(tg_methods)
    except OSError:
        pass
    for topic in topics:
        topicpath = os.path.join(project, topic)
        try:
            os.mkdir(topicpath)
        except OSError:
            pass
        if isotherms:
            isograd = os.path.join(topicpath, "isotherm")
            try:
                os.mkdir(isograd)
            except OSError:
                pass
            utils.isograder(isograd, isotherms, methods)

        if gradients:
            isograd = os.path.join(topicpath, "gradient")
            try:
                os.mkdir(isograd)
            except OSError:
                pass
            utils.isograder(isograd, gradients, methods)


def main():
    def represent_none(self, _):
        return self.represent_scalar("tag:yaml.org,2002:null", "")

    yaml.add_representer(type(None), represent_none)

    parameters = os.path.join(os.getcwd(), "parameters.yaml")
    try:
        with open(parameters, "r") as stream:
            data_loaded = yaml.safe_load(stream)
            try:
                run(*utils.decompress(data_loaded))
            except TypeError as e:
                print("Please double-check your parameters.yaml document'")
                try:
                    os.startfile(os.path.join(os.getcwd(), "parameters.yaml"))
                except OSError:
                    pass
            new_data, write_path = utils.write_post_yaml(data_loaded)
            with open(write_path, "w") as outfile:
                yaml.dump(new_data, outfile, default_flow_style=False)
            with open(
                os.path.join(new_data.get("DIRECTORY"), "compile.CMD"), "w"
            ) as outfile:
                cmdlet = ai.cmd()
                outfile.writelines(cmdlet)
    except FileNotFoundError as e:
        data_loaded = utils.write_yaml()
        with open("parameters.yaml", "w") as outfile:
            yaml.dump(data_loaded, outfile, default_flow_style=False)
        print("Please fill out the parameter.yaml document")
        try:
            os.startfile(os.path.join(os.getcwd(), "parameters.yaml"))
        except OSError:
            pass


if __name__ == "__main__":
    main()



import os


def write_yaml(data=None):
    if data:
        r_dict = {
            "DIRECTORY": data.get("DIRECTORY"),
            "BASELINE DIRECTORY": data.get("BASELINE DIRECTORY"),
            "GRADIENT": data.get("GRADIENTS", [10]),
            "ISOTHERMS": data.get("ISOTHERMS", []),
            "WAVE LENGTHS": data.get("WAVE LENGTHS", [1, 2, 3]),
            "RMS": data.get("RMS", False),
            "TECHNIQUES": data.get("TECHNIQUES"),
        }
    else:
        r_dict = {
            "DIRECTORY": os.getcwd(),
            "PROJECT": "VERY NICE",
            "TOPICS": ["WOW WHAT A TOPIC", "VERY GOOD CHOICE", "NICE", "WELL DONE",],
            "GRADIENTS": [10],
            "ISOTHERMS": [190, 220, 350],
            "TECHNIQUES": {
                "STA": True,
                "IR": True,
                "GC": False,
                "MS": True,
                "TG": False,
            },
        }
    return r_dict


def write_post_yaml(data):
    new_data = write_yaml(data)
    root = data.get("DIRECTORY", os.getcwd())
    project_name = data.get("PROJECT", "<NAME MISSING>")
    project = os.path.join(root, f"Project {project_name}")
    new_data["DIRECTORY"] = project
    write_path = os.path.join(project, "project parameters.yaml")
    parameters = os.path.join(project, "Parameters")
    baseline = os.path.join(parameters, "Baseline")
    new_data["BASELINE DIRECTORY"] = baseline
    return new_data, write_path


def decompress(data_loaded):
    root = data_loaded.get("DIRECTORY", os.getcwd())
    project_name = data_loaded.get("PROJECT", "<NAME MISSING>")
    project = os.path.join(root, f"Project {project_name}")
    isotherms = [iso for iso in data_loaded.get("ISOTHERMS") if iso]
    gradients = [grad for grad in data_loaded.get("GRADIENTS") if grad]
    methods = [
        method
        for method in data_loaded.get("TECHNIQUES")
        if data_loaded.get("TECHNIQUES")[method]
    ]
    topics = [f"Topic {topic}" for topic in data_loaded.get("TOPICS") if topic]
    parameters = os.path.join(project, "Parameters")
    baseline = os.path.join(parameters, "Baseline")
    tg_methods = os.path.join(parameters, "Method")
    return (
        project,
        topics,
        methods,
        isotherms,
        gradients,
        parameters,
        baseline,
        tg_methods,
    )


def isograder(isograd, temperature, methods):
    for temp in temperature:
        iso_path = os.path.join(isograd, str(temp))
        try:
            os.mkdir(iso_path)
        except OSError:
            pass
        try:
            for method in methods:
                iso_method_path = os.path.join(iso_path, method)
                os.mkdir(iso_method_path)
        except OSError:
            continue
